@@ -3,7 +3,7 @@
 # Crypt::HashCash::Stash - Coin Stash for HashCash Digital Cash
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/Stash.pm v1.120 Tue Jun 13 02:59:49 PDT 2017 $
+# $Id: lib/Crypt/HashCash/Stash.pm v1.121 Wed Jun 14 11:55:20 PDT 2017 $
 
 package Crypt::HashCash::Stash;
 
@@ -14,7 +14,7 @@ use Crypt::HashCash::Coin;
 use Crypt::HashCash::Client;
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.120 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.121 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my ($class, %arg) = @_;
@@ -251,8 +251,8 @@ Crypt::HashCash::Stash - Coin Stash for HashCash Digital Cash
 
 =head1 VERSION
 
- $Revision: 1.120 $
- $Date: Tue Jun 13 02:59:49 PDT 2017 $
+ $Revision: 1.121 $
+ $Date: Wed Jun 14 11:55:20 PDT 2017 $
 
 =head1 SYNOPSIS
 
@@ -260,21 +260,11 @@ Crypt::HashCash::Stash - Coin Stash for HashCash Digital Cash
 
   my $stash = new Crypt::HashCash::Stash;
 
-  $client->loadkeys;                           # Load vault keys
-
-  my $request = $client->request_coin          # Request a coin
-    ( Denomination => $denomination,
-      Init => $init );
-
-  my $coin = $client->unblind_coin($blindcoin) # Unblind a blinded coin
-
-  print "OK\n" if $client->verify_coin($coin)  # Verify coin's signature
-
 =head1 DESCRIPTION
 
-This module implements a client for the HashCash digital cash
-system. It provides methods to request, unblind and verify the
-signature on HashCash coins.
+This module implements a coin stash for the HashCash digital cash
+system. It provides methods to get coins from and add coins to the
+stash.
 
 =head1 METHODS
 
@@ -318,7 +308,7 @@ progress on your bug as I make changes.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Crypt::HashCash::Client
+    perldoc Crypt::HashCash::Stash
 
 You can also look for information at:
 
