@@ -3,7 +3,7 @@
 # Crypt::HashCash::Vault::Bitcoin - Bitcoin Vault for HashCash Digital Cash
 # Copyright (c) 2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/Vault/Bitcoin.pm v1.120 Tue Jun 13 02:59:50 PDT 2017 $
+# $Id: lib/Crypt/HashCash/Vault/Bitcoin.pm v1.121 Wed Jun 14 11:55:20 PDT 2017 $
 
 package Crypt::HashCash::Vault::Bitcoin;
 
@@ -20,7 +20,7 @@ use Business::Bitcoin;
 use Authen::TuringImage;
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.120 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.121 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my ($class, %arg) = @_;
@@ -82,8 +82,9 @@ sub keygen {
   my $vaultid = _dec(uc(md5_hex($spk)));
   return unless my $vaultcfg = new Persistence::Object::Simple ('__Fn' => "$keydbpath/$vaultid.cfg");
   $self->mint->keygen; $vaultcfg->{pub} = $keydb->{pub};
-  $keydb->{name} = $vaultcfg->{name} = $arg{Name};
-  $keydb->{server} = $vaultcfg->{server} = $arg{Server};
+  $keydb->{name} = $vaultcfg->{name} = $arg{Name} || 'localhost';
+  $keydb->{server} = $vaultcfg->{server} = $arg{Server} || 'localhost';
+  $keydb->{port} = $vaultcfg->{port} = $arg{Port} || '20203';
   $keydb->{sigscheme} = $vaultcfg->{sigscheme} = $self->mint->sigscheme;
   my ($pk,$sk) = $eecdh->keygen(PrivateKey => $ssk, PublicKey => $spk);
   $keydb->{vaultsigsec} = unpack('H*',$ssk);
@@ -459,8 +460,8 @@ Crypt::HashCash::Vault::Bitcoin - Bitcoin Vault for HashCash Digital Cash
 
 =head1 VERSION
 
- $Revision: 1.120 $
- $Date: Tue Jun 13 02:59:50 PDT 2017 $
+ $Revision: 1.121 $
+ $Date: Wed Jun 14 11:55:20 PDT 2017 $
 
 =head1 SYNOPSIS
 
